@@ -19,6 +19,7 @@ from Products.Archetypes.public import (
     DisplayList,
     Schema,
 )
+from Products.CMFCore.permissions import ModifyPortalContent
 from Products.ATContentTypes.content.base import registerATCT
 from Products.ATContentTypes.content.folder import ATFolderSchema, ATFolder
 
@@ -67,6 +68,7 @@ PFGVerkkomaksutSchema = ATFolderSchema.copy() + formMailerAdapterSchema.copy() +
         searchable=False,
         languageIndependent=True,
         storage=AnnotationStorage(),
+        read_permission=ModifyPortalContent,
         widget=BooleanWidget(
             label=_(u'Message Necessary'),
             description=_(u'If message after success of form input is necessary to send, please check this box.'),
@@ -74,13 +76,13 @@ PFGVerkkomaksutSchema = ATFolderSchema.copy() + formMailerAdapterSchema.copy() +
     ),
 
     LinesField(
-#        name='attachments_before_verkkomaksut',
         name='msg_attachments',
         schemata='message',
         required=False,
         searchable=False,
         languageIndependent=True,
         storage=AnnotationStorage(),
+        read_permission=ModifyPortalContent,
         widget=MultiSelectionWidget(
             label=_(u'E-mail attachments before Verkkomaksut'),
             description=_(u'Please select the attachments to be sent with email when one has successfully finished inputs of the form.'),
@@ -96,6 +98,7 @@ PFGVerkkomaksutSchema = ATFolderSchema.copy() + formMailerAdapterSchema.copy() +
         required=True,
         searchable=False,
         storage=AnnotationStorage(),
+        read_permission=ModifyPortalContent,
         widget=IntegerWidget(
             label=_(u'Merchant ID'),
             description=_(u'Please input MERCHANT_ID provided by Verkkomaksut here. The default ID is for demo use which is 13466.'),
@@ -111,6 +114,7 @@ PFGVerkkomaksutSchema = ATFolderSchema.copy() + formMailerAdapterSchema.copy() +
         required=True,
         searchable=False,
         storage=AnnotationStorage(),
+        read_permission=ModifyPortalContent,
             widget=StringWidget(
                 label=_(u'Merchant Authentication Code'),
                 description=_(u'Please input Merchant Authentication Code provided by Verkkomaksut here. The default ID is for demo use which is 6pKF4jkv97zmqBJ3ZL8gUw5DfT2NMQ.'),
@@ -125,6 +129,7 @@ PFGVerkkomaksutSchema = ATFolderSchema.copy() + formMailerAdapterSchema.copy() +
         required=True,
         searchable=False,
         storage=AnnotationStorage(),
+        read_permission=ModifyPortalContent,
         widget=IntegerWidget(
             label=_(u'Next Order Number'),
             description=_(u'Please input the next order number here. This number will be automatically increased by one for each transaction and will be sent to Verkkomksut.'),
@@ -141,6 +146,7 @@ PFGVerkkomaksutSchema = ATFolderSchema.copy() + formMailerAdapterSchema.copy() +
         searchable=False,
         languageIndependent=True,
         storage=AnnotationStorage(),
+        read_permission=ModifyPortalContent,
         widget=SelectionWidget(
             label=_(u'Price Field'),
             description=_(u'Please select the price field which will be used for Verkkomakusut. Remember to add fixed-point field or selection field with required option checked to the form folder first.'),
@@ -156,6 +162,7 @@ PFGVerkkomaksutSchema = ATFolderSchema.copy() + formMailerAdapterSchema.copy() +
         searchable=False,
         languageIndependent=True,
         storage=AnnotationStorage(),
+        read_permission=ModifyPortalContent,
         widget=LinesWidget(
             label=_(u'Order Description'),
             description=_(u'Please line up the ID of the field to be added to the ORDER_DESCRIPTION for verkkomaksut.'),
@@ -188,6 +195,7 @@ PFGVerkkomaksutSchema = ATFolderSchema.copy() + formMailerAdapterSchema.copy() +
         required=False,
         searchable=False,
         storage=AnnotationStorage(),
+        read_permission=ModifyPortalContent,
             widget=StringWidget(
                 label=_(u'Cancel Message'),
                 description=_(u'This message will be shown when one cancels Verkkomaksut payment.'),
